module.exports = defineTest({
	description: 'supports using an async function as config',
	command: 'rollup -c'
});
